/* Sentinel - IRC Statistical and Operator Services
** ircdsup.c - Sentinel ircd related supplemental functions.
**
** Copyright W. Campbell and others.  See README for more details
** Some code Copyright: Jonathan George, Kai Seidler, ircd-hybrid Team,
**                      IRCnet IRCD developers.
**
** $Id: ircdsup.c,v 1.4 2003/05/23 13:18:47 wcampbel Exp $
*/

#include "stats.h"
#include "struct.h"
#include "proto.h"

void introduce_nick(char *nick, char *username, char *hostname, char *gecos,
                    char *modes)
{
#ifndef IRCD_2_10
#ifdef USE_CURRENT_TS

  time_t now = time(NULL);
#else

  time_t now = 1;
#endif
#endif

#if defined(IRCD_HYBRID) || defined(IRCD_HYB6) || defined(IRCD_HYB7) || \
    defined(IRCD_HYBSVS)

  sts("NICK %s %ld 1 +%s %s %s %s :%s",
      nick, now, modes, username, hostname, settings.name, gecos);
#elif defined(IRCD_2_10)

  sts("NICK %s 1 %s %s 1 +%s :%s", nick, username, hostname, modes, gecos);
#elif defined(IRCD_BAHAMUT)

  sts("NICK %s %ld 1 +%s %s %s %s 1 :%s",
      nick, now, modes, username, hostname, settings.name, gecos);
#endif
}

void set_oper(struct User *u, unsigned int flag, unsigned int operflag)
{
  IncreaseOpers(u->server);
  u->flags |= flag;
#ifdef OPER_MODES

  u->operflags |= operflag;
#endif

  AddOperToList(&global_oper_list, u);
}

void join_channel(char *channel, struct User *u, unsigned int flag)
{
  struct Channel *c;

#if defined(IRCD_HYBRID) || defined(IRCD_HYB6) || defined(IRCD_HYB7) || \
    defined(IRCD_BAHAMUT) || defined(IRCD_HYBSVS)

  time_t now = time(NULL);

  sts(":%s SJOIN %ld %s + :@%s", settings.name, now, channel, u->nick);
#elif defined(IRCD_2_10)

  sts(":%s NJOIN %s :@%s", settings.name, channel, u->nick);
#endif

  c = findchannel(channel);
  if (c == NULL)
#ifdef IRCD_2_10

    c = AddChannel(channel);
#else

    c = AddChannel(channel, now);
#endif

  AddUserFlagToChannel(c, u, flag);
}
