/* Sentinel - IRC Statistical and Operator Services
** sql.c - MySQL handling functions.
**
** Copyright W. Campbell and others.  See README for more details
** Some code Copyright: Jonathan George, Kai Seidler, ircd-hybrid Team,
**                      IRCnet IRCD developers.
**
** This file copyrighted to Ilya Shtift (gate) <ishtift@tagil.svrw.ru>
**
** $Id: sql.c,v 1.2 2003/07/18 01:41:25 wcampbel Exp $
*/

#include "setup.h"
#include "stats.h"
#include "struct.h"
#include "proto.h"
#include "sql.h"
#ifdef HAVE_MYSQL
#include <mysql.h>

MYSQL *myptr;

void db_connect()
{
  if (!IsSQL())
    return;
  if (myptr)
    mysql_close(myptr);

  myptr = mysql_init(NULL);
  if (!mysql_real_connect(myptr, settings.sql_server, settings.sql_user,
                          settings.sql_password, settings.sql_database, 0, NULL, 0))
  {
    slog(L_CRIT, "Failed to connect to database : %s", mysql_error(myptr));
    return;
  }
}

void db_close()
{
  if (!IsSQL())
    return;
  if (myptr)
    mysql_close(myptr);
}

int db_query(const char *fmt, ...)
{
  va_list args;
  char buf[2048];
  va_start(args, fmt);
  vsnprintf(buf, 2048, fmt, args);

  if (!IsSQL())
    return 0;
  if (mysql_real_query(myptr, buf, strlen(buf)))
  {
    slog(L_CRIT, "Query failed: %s", mysql_error(myptr));
    db_connect();
    if (!mysql_real_query(myptr, buf, strlen(buf)))
      return 0;
    return 1;
  }
  return 0;
}

char *db_escape(char *str)
{
  int size;
  char *buf = NULL;

  if (!IsSQL())
    return NULL;
  if ((size = (strlen(str)) * 2 +1))
  {
    buf = (char *) malloc(size);
    mysql_real_escape_string(myptr, buf, str, strlen(str));
  }
  return buf;
}

#endif
