/* Sentinel - IRC Statistical and Operator Services
** sqldump.c - MySQL dump equivalent to the datadump.
**
** Copyright W. Campbell and others.  See README for more details
** Some code Copyright: Jonathan George, Kai Seidler, ircd-hybrid Team,
**                      IRCnet IRCD developers.
**
** This file copyrighted to Ilya Shtift (gate) <ishtift@tagil.svrw.ru>
**
** $Id: sqldump.c,v 1.7 2003/07/18 01:21:57 wcampbel Exp $
*/

#include "setup.h"
#ifdef HAVE_MYSQL
#include <mysql.h>
#endif
#include "stats.h"
#include "struct.h"
#include "proto.h"

#define TABLE_SERVERS "servers"
#define TABLE_NETINFO "netinfo"
#define TABLE_DAILY "daily"

#ifdef HAVE_MYSQL
MYSQL *smyptr;
#endif

int sdb_query(const char *fmt, ...)
{
  va_list args;
  char buf[2048]; /* XXX define */
  va_start(args, fmt);
  vsnprintf(buf, 2048, fmt, args);
#ifdef HAVE_MYSQL

  if (mysql_real_query(smyptr, buf, strlen(buf)))
  {
    slog(L_CRIT, "Query failed: %s", mysql_error(smyptr));
    return 1;
  }
#endif
  return 0;
}

void sqldump(char *MysqlServer, char *MysqlUser, char *MysqlPassword, char *MysqlDatabase)
{
#ifdef HAVE_MYSQL
  struct Server *s;
  int i;

  if (smyptr)
    mysql_close(smyptr);

  smyptr = mysql_init(NULL);
  if (!mysql_real_connect(smyptr, MysqlServer, MysqlUser, MysqlPassword, MysqlDatabase, 0, NULL, 0))
  {
    slog(L_CRIT, "Failed to connect to database : %s", mysql_error(smyptr));
    return ;
  }
  sdb_query("DELETE FROM " TABLE_NETINFO);
  sdb_query("DELETE FROM " TABLE_DAILY);
  sdb_query("DELETE FROM " TABLE_SERVERS);

  sdb_query("INSERT INTO " TABLE_NETINFO " VALUES "
           "('%u', '%ld', '%ld', FROM_UNIXTIME(%ld), '%d', '%d', "
           "FROM_UNIXTIME(%ld), '%d', '%d', FROM_UNIXTIME(%ld),"
           "'%d', '%d', FROM_UNIXTIME(%ld), '%d', FROM_UNIXTIME(%ld), '%ld', "
           "'%ld', FROM_UNIXTIME(%ld), '%d')",
           netinfo.away, netinfo.users, netinfo.maxusers,
           (long)netinfo.t_maxusers, netinfo.opers, netinfo.maxopers,
           (long)netinfo.t_maxopers, netinfo.servers, netinfo.maxservers,
           (long)netinfo.t_maxservers,
#ifdef IRCD_2_10
           netinfo.services, netinfo.maxservices,
           (long)netinfo.t_maxservices, netinfo.maxaway,
           (long)netinfo.t_maxaway,
#else
           0, 0, 0L, netinfo.maxaway, (long)netinfo.t_maxaway,
#endif
           netinfo.channels, netinfo.maxchannels,
           (long)netinfo.t_maxchannels, netinfo.invis);

  sdb_query("INSERT INTO " TABLE_DAILY " VALUES "
           "(NOW(), '%ld', FROM_UNIXTIME(%ld), '%d', FROM_UNIXTIME(%ld), '%d', "
           "FROM_UNIXTIME(%ld), '%d', FROM_UNIXTIME(%ld), '%ld', "
           "FROM_UNIXTIME(%ld))",
           daily.users, (long)daily.t_users, daily.opers,
           (long)daily.t_opers, daily.servers, (long)daily.t_servers,
#ifdef IRCD_2_10
           daily.services, (long)daily.t_services,
#else
           0, 0L,
#endif
           daily.channels, (long)daily.t_channels);

  for (i = 0; i < S_TABLE_SIZE; i++)
  {
    for (s = serverlist[i]; s; s = s->next)
    {
      sdb_query("INSERT INTO " TABLE_SERVERS " VALUES "
               "('%s', '%d', '%ld', '%ld', FROM_UNIXTIME(%ld), '%d', '%d', "
               "FROM_UNIXTIME(%ld), '%d', '%u', '%u', '%d', '%d', FROM_UNIXTIME(%ld), "
               "'%d', '%d', FROM_UNIXTIME(%ld), '%ld')",
               s->name, IsSHide(s) ? 1 : 0, s->users,
               s->stats->maxusers, (long)s->stats->t_maxusers,
               s->opers, s->stats->maxopers,
               (long)s->stats->t_maxopers, s->stats->numsplits,
               s->stats->operkills, s->stats->serverkills,
#ifdef IRCD_2_10
               s->services, s->stats->maxservices,
               (long)s->stats->t_maxservices, s->away,
               s->stats->maxaway, (long)s->stats->t_maxaway, s->invis);
#else

               0, 0, 0L, s->away, s->stats->maxaway,
               (long)s->stats->t_maxaway, s->invis);
#endif

    }
  }

  mysql_close(smyptr);
  smyptr = NULL;
#endif
}
